@@ -5,7 +5,7 @@ from oath import accept_totp
 
 class TokenBackend(ModelBackend):
     def authenticate(self, user, token):
-        accepted, drift = accept_totp(token, user.token.seed)
+        accepted, drift = accept_totp(key=user.token.seed, response=token)
         return user if accepted else None
 
 
